@@ -62,7 +62,7 @@ class UnshardedPrecomputedSkeletonSource(object):
       else returns a single Skeleton
     """
     list_return = True
-    if type(segids) in (int, float):
+    if isinstance(segids, (int,float,np.integer)):
       list_return = False
       segids = [ int(segids) ]
 
@@ -80,11 +80,15 @@ class UnshardedPrecomputedSkeletonSource(object):
     if not allow_missing and len(missing):
       raise SkeletonDecodeError("File(s) do not exist: {}".format(", ".join(missing)))
 
+    vertex_attributes = self.meta.info.get("vertex_attributes", [])
+
     skeletons = []
     for filename, content in results.items():
       segid = int(os.path.basename(filename))
       try:
-        skel = Skeleton.from_precomputed(content, segid=segid)
+        skel = Skeleton.from_precomputed(
+          content, segid=segid, vertex_attributes=vertex_attributes
+        )
       except Exception as err:
         raise SkeletonDecodeError("segid " + str(segid) + ": " + str(err))
       skel.transform = self.meta.transform
@@ -105,16 +109,21 @@ class UnshardedPrecomputedSkeletonSource(object):
       vertex_types, segid=segid
     )
     return self.upload(skel)
-    
+  
   @readonlyguard
   def upload(self, skeletons):
+
+    compress = self.config.compress 
+    if compress is None:
+      compress = True
+
     if type(skeletons) == Skeleton:
       skeletons = [ skeletons ]
 
     files = [ (self.meta.join(self.meta.skeleton_path, str(skel.id)), skel.to_precomputed()) for skel in skeletons ]
     self.cache.upload(
       files=files, 
-      compress='gzip', 
+      compress=compress, 
       cache_control=cdn_cache_control(self.config.cdn_cache)
     )
 
