@@ -261,14 +261,18 @@ def check_bounds(val, low, high):
 
 class Vec(np.ndarray):
     def __new__(cls, *args, **kwargs):
-      if 'dtype' in kwargs:
-        dtype = kwargs['dtype']
-      elif floating(args):
-        dtype = float
-      else:
-        dtype = int
-
-      return super(Vec, cls).__new__(cls, shape=(len(args),), buffer=np.array(args).astype(dtype), dtype=dtype)
+      dtype = kwargs.pop('dtype', None)
+      if dtype is None:
+        if floating(args):
+          dtype = float
+        else:
+          dtype = int
+      
+      return super().__new__(
+        cls, shape=(len(args),), 
+        buffer=np.array(args, dtype=dtype), 
+        dtype=dtype
+      )
 
     @classmethod
     def clamp(cls, val, minvec, maxvec):
@@ -317,9 +321,13 @@ Vec.b = Vec.z
 Vec.a = Vec.w
 
 def floating(lst):
-  return any(( isinstance(x, float) for x in lst ))
+  for x in lst:
+    if isinstance(x, float):
+      return True
+  return False
 
-FILENAME_RE = re.compile(r'(-?\d+)-(-?\d+)_(-?\d+)-(-?\d+)_(-?\d+)-(-?\d+)(?:\.gz|\.br)?$')
+FLT_RE = r'(-?\d+(?:\.\d+)?)' # floating point regexp
+FILENAME_RE = re.compile(fr'{FLT_RE}-{FLT_RE}_{FLT_RE}-{FLT_RE}_{FLT_RE}-{FLT_RE}(?:\.gz|\.br|\.zstd)?$')
 
 class Bbox(object):
   __slots__ = [ 'minpt', 'maxpt', '_dtype' ]
@@ -380,7 +388,12 @@ class Bbox(object):
 
   @classmethod
   def intersects(cls, bbx1, bbx2):
-    return np.all(bbx1.minpt < bbx2.maxpt) and np.all(bbx1.maxpt > bbx2.minpt)
+    a = bbx1.minpt < bbx2.maxpt
+    b = bbx1.maxpt > bbx2.minpt
+    c = a & b
+    if len(c) == 3:
+      return c[0] & c[1] & c[2]
+    return np.all(c)
 
   @classmethod
   def near_edge(cls, bbx1, bbx2, distance=0):
@@ -432,14 +445,18 @@ class Bbox(object):
 
   @classmethod
   def from_filename(cls, filename, dtype=int):
-    match = FILENAME_RE.search(os.path.basename(filename))
+    fname = os.path.basename(filename)
+    match = FILENAME_RE.search(fname)
 
     if match is None:
-      raise ValueError("Unable to decode bounding box from: " + str(filename))
+      raise ValueError(f"Unable to decode bounding box from: {filename}")
+
+    root, ext = os.path.splitext(fname)
+    parse_type = float if '.' in root else int
 
     (xmin, xmax,
      ymin, ymax,
-     zmin, zmax) = map(int, match.groups())
+     zmin, zmax) = map(parse_type, match.groups())
 
     return Bbox( (xmin, ymin, zmin), (xmax, ymax, zmax), dtype=dtype)
 
@@ -761,10 +778,25 @@ class Bbox(object):
 
     Returns: boolean
     """
-    return np.all(point >= self.minpt) and np.all(point <= self.maxpt)
+    for x in (point < self.minpt):
+      if x:
+        return False
+    for x in (point > self.maxpt):
+      if x:
+        return False
+    return True
 
   def contains_bbox(self, bbox):
-    return self.contains(bbox.minpt) and self.contains(bbox.maxpt)
+    return (
+      self.contains(bbox.maxpt)
+      and self.contains(bbox.minpt) 
+    )
+
+  def overlaps_bbox(self, bbox):
+    return not (
+      np.any(self.maxpt < bbox.minpt)
+      or np.any(self.minpt > bbox.maxpt)
+    )
 
   def clone(self):
     return Bbox(self.minpt, self.maxpt, dtype=self.dtype)
