@@ -291,9 +291,9 @@ class SegmentationVolume extends MonoVolume {
       z = slice;
     }
 
-    x = Math.round(x);
-    y = Math.round(y);
-    z = Math.round(z);
+    x = Math.floor(x);
+    y = Math.floor(y);
+    z = Math.floor(z);
 
     let segid = _this.channel.get(x, y, z);
     
@@ -314,7 +314,7 @@ class SegmentationVolume extends MonoVolume {
   }
 }
 
-/* Volume
+/* HyperVolume
  *
  * Represents a 3D bounding box in the data set's global coordinate space.
  * Contains two types of images: channel (raw EM images), 
@@ -326,7 +326,7 @@ class SegmentationVolume extends MonoVolume {
  *   segmentation: A blankable Datacube representing segmentation values.
  *      Seg ids don't appear to rise above the high thousands, so 2 bytes is probably sufficent.
  *
- * Return: Volume object
+ * Return: HyperVolume object
  */
 class HyperVolume extends MonoVolume {
   constructor (channel, segmentation) {
@@ -447,9 +447,10 @@ class HyperVolume extends MonoVolume {
     const brightener = this.colorToUint32({ r: 10, g: 10, b: 10, a: 0 });
     const hover_id = this.hover_id;
 
+    let segments = this.segments;
     let selected_segments = new Uint8Array(this.renumbering.length);
     Object.keys(_this.segments).forEach((label) => {
-      selected_segments[label] = 1;
+      selected_segments[label] = !!segments[label];
     });
 
     let pxdata = pixels.data;
@@ -526,9 +527,9 @@ class HyperVolume extends MonoVolume {
       z = slice;
     }
 
-    x = Math.round(x);
-    y = Math.round(y);
-    z = Math.round(z);
+    x = Math.floor(x);
+    y = Math.floor(y);
+    z = Math.floor(z);
 
     let segid = _this.segmentation.get(x, y, z);
     
@@ -538,6 +539,15 @@ class HyperVolume extends MonoVolume {
 
     return segid;
   }
+
+  selectSegment(segid) {
+    let _this = this;
+    segid = _this.segmentation.cast(segid);
+    segid = _this.renumbering.indexOf(segid);
+    if (segid !== -1) {
+      _this.segments[segid] = true;
+    }
+  }
 }
 
 class CachedImageData {
