@@ -128,6 +128,17 @@ class Skeleton(object):
       }
     ]
 
+  def add_vertex_attribute(self, name:str, arr:np.ndarray):
+    """
+    Add a new vertex attribute type and its data.
+    """
+    self.extra_attributes.append({
+      "id": name,
+      "data_type": np.dtype(arr.dtype).name,
+      "num_components": (1 if arr.ndim == 1 else arr.shape[2]),
+    })
+    setattr(self, name, arr)
+
   def _check_space(self):
     if self.space not in ('physical', 'voxel'):
       raise SkeletonTransformError(
@@ -265,10 +276,19 @@ class Skeleton(object):
       edges.append(edge)
       ct += skel.vertices.shape[0]
 
+    space = skeletons[0].space
+    if space == "voxel":
+      skeletons = [ s.voxel_space() for s in skeletons ]
+    else:
+      skeletons = [ s.physical_space() for s in skeletons ]
+
     skel = Skeleton(
       vertices=np.concatenate([ skel.vertices for skel in skeletons ], axis=0),
       edges=np.concatenate(edges, axis=0),
       segid=skeletons[0].id,
+      extra_attributes=skeletons[0].extra_attributes,
+      space=space,
+      transform=skeletons[0].transform,
     )
 
     if len(skeletons) == 0:
@@ -538,7 +558,12 @@ class Skeleton(object):
     edges = self.edges 
 
     if self.empty():
-      return Skeleton(segid=self.id)
+      return Skeleton(
+        segid=self.id, 
+        space=self.space, 
+        extra_attributes=self.extra_attributes,
+        transform=self.transform,
+      )
     
     eff_vertices, uniq_idx, idx_representative = np.unique(
       nodes, axis=0, return_index=True, return_inverse=True
@@ -550,7 +575,13 @@ class Skeleton(object):
     eff_edges = np.unique(eff_edges, axis=0)
     eff_edges = eff_edges[ eff_edges[:,0] != eff_edges[:,1] ] # remove trivial loops
 
-    skel = Skeleton(eff_vertices, eff_edges, segid=self.id)
+    skel = Skeleton(
+      eff_vertices, eff_edges, 
+      segid=self.id, 
+      space=self.space,
+      extra_attributes=self.extra_attributes,
+      transform=self.transform,
+    )
 
     for attr in self.extra_attributes:
       name = attr['id']
@@ -571,13 +602,23 @@ class Skeleton(object):
     Returns: new Skeleton
     """
     if self.empty():
-      return Skeleton(segid=self.id)
+      return Skeleton(
+        segid=self.id, 
+        space=self.space, 
+        extra_attributes=self.extra_attributes,
+        transform=self.transform,
+      )
+
+    all_edges = fastremap.unique(self.edges.flat)
+
+    if len(self.vertices) == all_edges.size:
+      return self.clone()
 
     idx_map = {}
     for i, vert in enumerate(self.vertices):
       idx_map[tuple(vert)] = i
 
-    connected_verts = np.unique(self.vertices[ self.edges.flatten() ], axis=0)
+    connected_verts = np.unique(self.vertices[ self.edges.flat ], axis=0)
 
     edge_map = np.zeros( (len(self.vertices),), dtype=self.edges.dtype)
     vertex_remap = np.zeros( (len(self.vertices),), dtype=np.int32) - 1
@@ -589,7 +630,13 @@ class Skeleton(object):
     edges = np.sort(edge_map[self.edges], axis=1)
     vertex_remap = vertex_remap[ vertex_remap > -1 ]
 
-    skel = Skeleton(connected_verts, edges, segid=self.id)
+    skel = Skeleton(
+      connected_verts, edges, 
+      segid=self.id, 
+      space=self.space,
+      extra_attributes=self.extra_attributes,
+      transform=self.transform,
+    )
 
     if len(self.extra_attributes) == 0:
       return skel
@@ -852,7 +899,7 @@ class Skeleton(object):
       return np.unique(edge_list[1:], axis=0)
 
     forest = []
-    for edge in fastremap.unique(skel.edges.flatten()):
+    for edge in fastremap.unique(skel.edges.flat):
       if visited[edge]:
         continue
 
@@ -883,16 +930,22 @@ class Skeleton(object):
       vert_idx = fastremap.unique(edge_list)
 
       vert_list = skel.vertices[vert_idx]
-      radii = skel.radii[vert_idx]
-      vtypes = skel.vertex_types[vert_idx]
 
       remap = { vid: i for i, vid in enumerate(vert_idx) }
       edge_list = fastremap.remap(edge_list, remap, in_place=True)
 
-      skeletons.append(
-        Skeleton(vert_list, edge_list, radii, vtypes, skel.id)
+      component_skel = Skeleton(
+        vert_list, edge_list,# radii, vtypes, 
+        segid=skel.id,
+        extra_attributes=self.extra_attributes,
       )
 
+      for attr in self.extra_attributes:
+        vals = getattr(skel, attr['id'])[vert_idx]
+        setattr(component_skel, attr['id'], vals)
+
+      skeletons.append(component_skel)
+
     return skeletons
 
   @classmethod
@@ -1075,7 +1128,6 @@ class Skeleton(object):
     """
     try:
       import matplotlib.pyplot as plt
-      from mpl_toolkits.mplot3d import Axes3D 
       from matplotlib import cm
     except ImportError:
       print("Skeleton.viewer requires matplotlib. Try: pip install matplotlib --upgrade")
@@ -1085,7 +1137,7 @@ class Skeleton(object):
     COMPONENT_KEYWORDS = ('component', 'components', 'c')
 
     fig = plt.figure(figsize=(10,10))
-    ax = Axes3D(fig)
+    ax = fig.add_subplot(projection='3d')
     ax.set_xlabel(units)
     ax.set_ylabel(units)
     ax.set_zlabel(units)
