@@ -638,21 +638,20 @@ def test_simple_merge():
 
   assert result == expected
 
-  skel1.extra_attributes = [{
+  wow_attr = {
     "id": "wow",
     "data_type": "uint8",
     "components": 1,
-  }]
+  }
+
+  skel1.extra_attributes = [copy.deepcopy(wow_attr)]
   skel1.wow = np.array([1,2,3], dtype=np.uint8)
 
-  skel2.extra_attributes = [{
-    "id": "wow",
-    "data_type": "uint8",
-    "components": 1,
-  }]
+  skel2.extra_attributes = [copy.deepcopy(wow_attr)]
   skel2.wow = np.array([4,5,6], dtype=np.uint8)
 
   result = Skeleton.simple_merge([ skel1, skel2 ])
+  expected.extra_attributes = [copy.deepcopy(wow_attr)]
   expected.wow = np.array([1,2,3,4,5,6], dtype=np.uint8)
 
   assert result == expected
@@ -671,6 +670,7 @@ def test_simple_merge():
     "data_type": "float32",
     "components": 2,
   })
+  skel2.amaze = np.array([])
 
   try:
     Skeleton.simple_merge([ skel1, skel2 ])
